==> kubernetes-model-1.0.57-sources.jar: io/fabric8/openshift/api/model/SignatureIssuerBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class SignatureIssuerBuilder extends SignatureIssuerFluentImpl<SignatureIssuerBuilder> implements VisitableBuilder<SignatureIssuer,SignatureIssuerBuilder>{

    SignatureIssuerFluent<?> fluent;
    Boolean validationEnabled;

    public SignatureIssuerBuilder(){
            this(true);
    }
    public SignatureIssuerBuilder(Boolean validationEnabled){
            this(new SignatureIssuer(), validationEnabled);
    }
    public SignatureIssuerBuilder(SignatureIssuerFluent<?> fluent){
            this(fluent, true);
    }
    public SignatureIssuerBuilder(SignatureIssuerFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new SignatureIssuer(), validationEnabled);
    }
    public SignatureIssuerBuilder(SignatureIssuerFluent<?> fluent,SignatureIssuer instance){
            this(fluent, instance, true);
    }
    public SignatureIssuerBuilder(SignatureIssuerFluent<?> fluent,SignatureIssuer instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCommonName(instance.getCommonName()); 
            fluent.withOrganization(instance.getOrganization()); 
            this.validationEnabled = validationEnabled; 
    }
    public SignatureIssuerBuilder(SignatureIssuer instance){
            this(instance,true);
    }
    public SignatureIssuerBuilder(SignatureIssuer instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCommonName(instance.getCommonName()); 
            this.withOrganization(instance.getOrganization()); 
            this.validationEnabled = validationEnabled; 
    }

    public SignatureIssuer build(){
            SignatureIssuer buildable = new SignatureIssuer(fluent.getCommonName(),fluent.getOrganization());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SignatureIssuerBuilder that = (SignatureIssuerBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: io/fabric8/openshift/api/model/SignatureIssuerBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class SignatureIssuerBuilder extends SignatureIssuerFluentImpl<SignatureIssuerBuilder> implements VisitableBuilder<SignatureIssuer,SignatureIssuerBuilder>{

    SignatureIssuerFluent<?> fluent;
    Boolean validationEnabled;

    public SignatureIssuerBuilder(){
            this(true);
    }
    public SignatureIssuerBuilder(Boolean validationEnabled){
            this(new SignatureIssuer(), validationEnabled);
    }
    public SignatureIssuerBuilder(SignatureIssuerFluent<?> fluent){
            this(fluent, true);
    }
    public SignatureIssuerBuilder(SignatureIssuerFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new SignatureIssuer(), validationEnabled);
    }
    public SignatureIssuerBuilder(SignatureIssuerFluent<?> fluent,SignatureIssuer instance){
            this(fluent, instance, true);
    }
    public SignatureIssuerBuilder(SignatureIssuerFluent<?> fluent,SignatureIssuer instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withCommonName(instance.getCommonName()); 
            fluent.withOrganization(instance.getOrganization()); 
            this.validationEnabled = validationEnabled; 
    }
    public SignatureIssuerBuilder(SignatureIssuer instance){
            this(instance,true);
    }
    public SignatureIssuerBuilder(SignatureIssuer instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withCommonName(instance.getCommonName()); 
            this.withOrganization(instance.getOrganization()); 
            this.validationEnabled = validationEnabled; 
    }

    public SignatureIssuer build(){
            SignatureIssuer buildable = new SignatureIssuer(fluent.getCommonName(),fluent.getOrganization());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            SignatureIssuerBuilder that = (SignatureIssuerBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
